<!--*****************************************************************
*     UOC - TFC - Desarrollo de aplicaciones móviles HTML5          *
*																	*
* File: 	gestorBD.php                                            *
* 																	*
* Author: 	José María Polo Peromarta <chema@informaticapolo.com>   *
* 																	*
* Collaborator DB: Ezequiel Corredera <ezecor@gmail.com>            *
*																	* 		
* Date: 	23 April 2014                                           *
*																	*
* Inputs: 	general.css      										*
*           							                            *
* Outputs:	pruebaConexionBD()										*
*			getdb()													*
*			CargaEspecialidades()									*
*			CargaMedicos($espe,$zona)								*
*			CargaActividades($idzona)								*
*           CargaComercios($act,$zona)								*
*           MedicosPorServicio($idser)								*
*           CargaMedicosEspZon($espe, $zona)						*
*																	*
* Nota: 	Gestor de acceso a la base de datos	donde están todas	*
			las funciones.											*
******************************************************************-->

<!-- CSS de entrada -->
<link href="css/general.css" rel="stylesheet" type="text/css" />

<?php
//Para mostrar errores PHP 
error_reporting(E_ALL); 
ini_set("display_errors", 1);

//Debug:
function pruebaConexionBD(){
	echo "<h1>Prueba Conexion BD OK</h1>";
}


/*
    Tabla de usuario/medicos/centros

  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `tipo` varchar(3) NOT NULL                            indica si es un usuario ADM , MED o CEN',
  `titulo` varchar(10) DEFAULT NULL,                    Dr. Dra, D. Dña ...
  `nombre` varchar(60) DEFAULT NULL,                    si es un centro esta vacio
  `apellidos` varchar(60) NOT NULL,                     si es un centro aqui esta el nombre
  `dir1` varchar(100) DEFAULT NULL,
  `dir2` varchar(100) DEFAULT NULL,
  `cp` varchar(5) DEFAULT NULL,
  `pobla` varchar(45) DEFAULT NULL,
  `provincia` varchar(30) DEFAULT NULL,
  `cif` varchar(15) DEFAULT NULL,
  `tel1` varchar(15) DEFAULT NULL,
  `tel2` varchar(15) DEFAULT NULL,
  `fax` varchar(15) DEFAULT NULL,
  `email` varchar(45) DEFAULT NULL,
  `idespe` int(10) unsigned DEFAULT NULL,
  `activo` varchar(1) NOT NULL,
  `idzona` int(10) unsigned NOT NULL,
  `web` varchar(80) DEFAULT NULL,
  `obs` text,
  `nomlimpio` varchar(120) DEFAULT NULL,                contiene el nombre+apellidos todo en minusculas y sin acentos. Lo utilizamos para las busquedas.
*/

 
/*
    Devuelve una conexion a la bd
*/

//--------------------------------------------------------------------------
function getdb()
//--------------------------------------------------------------------------
{
	
    //Configuración si la pongo fuera al imbrigar pierde la ruta. 
	//TODO: Mejorar haciendo DAO (Driver Access Object - para la base de datos)
	//Borrados los datos por seguridad para su publicación
	$DbHost = '**********';
	$DbUser = '**********';
	$DbPass = '**********';  
	$DbName = '**********';
	
	try {
    
		$conn = new PDO("mysql:host=$DbHost;dbname=$DbName", $DbUser, $DbPass);
		$conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    	return $conn;
    
	} catch (PDOException $e) {
		
    	print "
			<div class='fondoMensajeError01'>
			
				<p class='mensajeError01'>Se ha producido un fallo al conectar con la Base de Datos: </p>
				<p><i>" . $e->getMessage() . "</i></p>
			
			</div><br/>";
		
    	die();
		
		
	}
	
}


/*
Devuelve todas las especialidades por orden alfabetico y con su nº de medicos correspondientes
*/ 

//---------------------------------------------------------------------
function CargaEspecialidades()
//---------------------------------------------------------------------
{
    // cargar TODAS las especialidades con su nº de medicos
    $conn = getdb();
    $sql = $conn->prepare('
    select count(idusuario) as resultados,a.idespe,a.nombre
    from
    			( select distinct
                         b.idusuario,
                         b.idmedcen,
                         e.id as idespe,
                         e.nombre
                  from   baremos b, especialidades e, servicios s, usuarios u
                  where  b.idservicio=s.id
                  and    s.idespe=e.id
                  and    b.idusuario=u.id
                  and    u.activo="1"   
                ) a
    group by idespe,nombre
    order by a.nombre
    ');
    $sql->execute();
    $res = $sql->fetchAll(PDO::FETCH_ASSOC);
	$conn = null;
    return $res;
	
}


/*
    Devuelve todos los medicos de una especialidad.
    En el parametro $zona hay que pasar 0 y asi no la tiene en cuenta.
*/
//---------------------------------------------------------------------
function CargaMedicos($espe,$zona)
//---------------------------------------------------------------------
{
    $conn = getdb();
    $sql = $conn->prepare('select * from (
                            select id,titulo,nombre,apellidos,"" as nomcentro   
                            from   usuarios u
                            where  tipo="MED"
                            and    u.activo="1"
                            and    (:idzona=0 or idzona=:idzona)
                            and    idespe=:idespe
                            and	 exists
                            		 ( select 1
                            		   from   baremos b
                            		   where  b.idusuario=u.id
                            		 )
                            union all
                            select u.id, m.titulo,"" as nombre,m.apellidos,u.apellidos as nomcentro
                            from   usuarios u,medcen m
                            where  tipo="CEN"
                            and    u.activo="1"
                            and    m.idcentro=u.id
                            and    (:idzona=0 or idzona=:idzona)
                            and	 exists
                            		 ( select 1
                            		   from   baremos b, servicios s
                            		   where  b.idservicio = s.id
                            		   and    b.idmedcen = m.id
                            		   and    s.idespe = :idespe
                            		 )
                            ) xxx
                            order by xxx.apellidos,xxx.nombre
    ');
    $sql->execute(array('idzona' => $zona,
                        'idespe' => $espe
    ) );
    $res = $sql->fetchAll(PDO::FETCH_ASSOC);
    return $res;
}

/*Los comercios van agrupados por la actividad.
Devuelve las distintas actividades y el nº de comercios que hay en ellas.
Si el parametro de zona es 0 las devuelve todas.*/

//---------------------------------------------------------------------
//function CargaActividades($idzona=0)
function CargaActividades($idzona)
//---------------------------------------------------------------------
{
    // cargar TODAS las actividades con su nº de comercios
    $conn = getdb();
    $sql = $conn->prepare('
    select count(idact) as resultados,c.idact,a.nombre
    from comercios c, actividades a 
    where c.idact=a.id
    and (:idzona=0 or c.idzona=:idzona)
    and activo=1
    group by idact,nombre
    order by a.nombre    
    ');
    $sql->execute( array('idzona' => $idzona) );                            
    $res = $sql->fetchAll();
	$conn = null;
    return $res;
}

/*Devuelve los comercios de una actividad y opcionalmente de una zona.
Si necesitas mas datos del comercio*/

//---------------------------------------------------------------------
function CargaComercios($act,$zona)
//---------------------------------------------------------------------
{
    $conn = getdb();
    $sql = $conn->prepare('
                            select id,nombre,dir1,dir2,tel1,cp,pobla
                            from   comercios c
                            where  activo=1
                            and    (:idzona=0 or idzona=:idzona)
                            and    idact=:idact
                            order by nombre          
    ');
    $sql->execute(array('idzona' => $zona,
                        'idact'  => $act
    ) );                            
    $res = $sql->fetchAll();
    return $res;
}    


/*Devuelve los medicos/centros que tienen un servicio en su baremo. Ojo : puede haber más de uno.
Si es un medico (tipo='MED') su nombre esta en apellidos,nombre y nommedcen esta vacio
Si es un centro (tipo='CEN') el nombre del centro esta en apellidos y el nombre del medico esta en nommedcen*/


//---------------------------------------------------------------------
function MedicosPorServicio($idser)
//---------------------------------------------------------------------
{
			$conn = getdb();
            $sql = $conn->prepare('
            select x.*, m.apellidos as nommedcen, m.titulo as titmedcen
            from (
                        select u.id,u.tipo,titulo,u.nombre,apellidos,dir1,dir2,tel1,cp,pobla,s.idespe,b.precio,
                        		 b.idmedcen,b.id as idbaremo
                        from   usuarios u, baremos b, servicios s
                        where  ( tipo="MED" or tipo="CEN")
                        and    activo=1 
                        and    u.id=b.idusuario
                        and    b.idservicio=s.id
                        and    b.idservicio=:idser
               ) x
            left outer join medcen m on x.idmedcen= m.id                                
            order by apellidos,nombre,nommedcen
                                ');
            $sql->execute( array( 'idser' => $idser ));    
			$res = $sql->fetchAll();
			return $res;
}

/*Cuando el usuario selecciona por ejemplo Analisis clinicos el dato importante es la columna idespe de la select anterior.
Con ese dato, la funcion siguiente devuelve los medicos/centros que tienen esa especialidad : (el parametro zona es opcional).
*/

//---------------------------------------------------------------------
//function CargaMedicosEspZon($espe,$zona=0)
function CargaMedicosEspZon($espe, $zona)
//---------------------------------------------------------------------
{
    $conn = getdb();
    $sql = $conn->prepare('select * from (
                            select id,titulo,nombre,apellidos,"" as nomcentro, dir1, tel1   /* añadir campos */
                            from   usuarios u
                            where  tipo="MED"
                            and    u.activo="1"
                            and    (:idzona=0 or idzona=:idzona)
                            and    idespe=:idespe
                            and	 exists
                            		 ( select 1
                            		   from   baremos b
                            		   where  b.idusuario=u.id
                            		 )
                            union all
                            select u.id, m.titulo,"" as nombre,m.apellidos,u.apellidos as nomcentro, dir1, tel1      /* añadir campos */
                            from   usuarios u,medcen m
                            where  tipo="CEN"
                            and    u.activo="1"
                            and    m.idcentro=u.id
                            and    (:idzona=0 or idzona=:idzona)
                            and	 exists
                            		 ( select 1
                            		   from   baremos b, servicios s
                            		   where  b.idservicio = s.id
                            		   and    b.idmedcen = m.id
                            		   and    s.idespe = :idespe
                            		 )
                            ) xxx
							group by dir1
                            order by xxx.apellidos,xxx.nombre
							
    ');
    $sql->execute(array('idzona' => $zona,
                        'idespe' => $espe
    ) );
    $res = $sql->fetchAll(PDO::FETCH_ASSOC);
    return $res;
}